/*
 * SWE Ereigniskalender - Version 2
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49-341-49067-0
 * Fax: +49-341-49067-15
 * E-Mail: info@bitctrl.de
 */

package de.bsvrz.vew.ereigniskal.data;

/**
 * Definition der Verwendung vin Ereignissen nach Ereignistyp zur Beantwortung
 * einer Ereigniskalenderanfrage.
 * 
 * @author BitCtrl Systems GmbH, Uwe Peuker
 *
 */
public enum EreignisTypenOption {

    /** es werden alle Ereignisse in die Beantwortung einbezogen. */
    Alle(0),
    /**
     * es werden nur Ereignisse in die Beantwortung einbezogen, die den in einer
     * übergebenen Liste von Ereignistypen entsprechen.
     */
    Nur(1),
    /**
     * es werden nur Ereignisse in die Beantwortung einbezogen, die nicht den in
     * einer übergebenen Liste von Ereignistypen entsprechen.
     */
    Nicht(2);

    /**
     * liefert die Option, die mit dem übergebenen Code verknüpft ist.
     * 
     * @param code
     *            der Code
     * @return die {@link EreignisTypenOption}
     */
    public static EreignisTypenOption of(int code) {

        for (EreignisTypenOption option : values()) {
            if (option.code == code) {
                return option;
            }
        }
        throw new IllegalArgumentException("Ungültige Ereignistypenoption: " + code);
    }

    private int code;

    EreignisTypenOption(int code) {
        this.code = code;
    }
}
