/*
 * SWE Ereigniskalender - Version 2
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * BitCtrl Systems GmbH
 * Weißenfelser Straße 67
 * 04229 Leipzig
 * Phone: +49-341-49067-0
 * Fax: +49-341-49067-15
 * E-Mail: info@bitctrl.de
 */

package de.bsvrz.vew.ereigniskal.data;

import java.util.LinkedHashSet;
import java.util.Set;

import de.bsvrz.dav.daf.main.Data;
import de.bsvrz.dav.daf.main.Data.ReferenceArray;
import de.bsvrz.dav.daf.main.config.SystemObject;

/**
 * Definition der räumlichen Gültigkeit eines Ereignisses.
 * 
 * @author BitCtrl Systems GmbH, Uwe Peuker
 */
public class RaeumlicheGueltigkeit {

    /**
     * erzeugt eine Instanz der {@link RaeumlicheGueltigkeit} aus den
     * übergebenen Datenverteiler-Daten.
     * 
     * @param data
     *            die Daten
     * @return die neue Instanz
     */
    public static RaeumlicheGueltigkeit from(Data data) {
        RaeumlicheGueltigkeit raeumlicheGueltigkeit = new RaeumlicheGueltigkeit();
        ReferenceArray raumArray = data.getReferenceArray("RäumlicheGültigkeit");
        for (int idx = 0; idx < raumArray.getLength(); idx++) {
            raeumlicheGueltigkeit.addNetzBestandTeil(raumArray.getSystemObject(idx));
        }
        return raeumlicheGueltigkeit;
    }

    Set<SystemObject> bestandTeile = new LinkedHashSet<>();

    /**
     * fügt einen Netzbestandteil hinzu.
     * 
     * Es erfolgt keine Typprüfung des Systemobjekts!
     * 
     * @param bestandTeil
     *            der neue Bestandteil
     */
    public void addNetzBestandTeil(SystemObject bestandTeil) {
        bestandTeile.add(bestandTeil);
    }

    /**
     * ermittelt, ob die räumlische Gültigkeit mit den übergebenen
     * Systemobjekten gegeben ist.
     * 
     * Die räumliche Gültigkeit ist gegeben, wenn die Liste der zugeordneten
     * Netzbestandteile oder die Menge der angefragten Systemobjekt leer ist.
     * Anderenfalls ist die räumliche Gültigkeit erfüllt, wenn die Schnittmenge
     * aus zugeordneten Netzbestandteilen und angefragten Systemobjekten nicht
     * leer ist.
     * 
     * @param betrachteteNetzbestandteile
     *            die Menge der zu prüfenden Netzbestandteile
     * @return die Gültigkeit
     */
    public boolean istGueltigFuer(Set<SystemObject> betrachteteNetzbestandteile) {

        if (bestandTeile.isEmpty() || betrachteteNetzbestandteile.isEmpty()) {
            return true;
        }

        for (SystemObject so : bestandTeile) {
            if (betrachteteNetzbestandteile.contains(so)) {
                return true;
            }
        }

        return false;
    }
}